==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mi-NZ/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Kua whakakorea e tetahi kaiwhakamahi tetahi tonoemi i runga i te paetukutuku',
    'a_user_requested' => 'Kua tono tetahi kaiwhakamahi i tetahi mea i runga i te paetukutuku',
    'accessory_name' => 'Ingoa Whakauru:',
    'additional_notes' => 'Nga Tuhipoka Atu:',
    'admin_has_created' => 'Kua hanga e tetahi kaiwhakahaere tetahi kaute mo koe i runga i te: paetukutuku tukutuku.',
    'asset' => 'Tahua:',
    'asset_name' => 'Ingoa Ahua:',
    'asset_requested' => 'Ka tonohia te taonga',
    'asset_tag' => 'Tae Taonga',
    'assigned_to' => 'Tohua Ki To',
    'best_regards' => 'Ko nga whakaaro pai,',
    'canceled' => 'Kua whakakorehia:',
    'checkin_date' => 'Rangi Whakatau:',
    'checkout_date' => 'Rā Whakatau:',
    'click_to_confirm' => 'Tena koahia te hono e whai ake nei hei whakauru i to:',
    'click_on_the_link_accessory' => 'Tena koahia te hono i raro ki te whakauru kua whiwhi koe i te taputapu.',
    'click_on_the_link_asset' => 'Koahia te hono i raro ki te whakauru kua riro ia koe te taonga.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY o nāianei',
    'Days' => 'Nga ra',
    'days' => 'Nga ra',
    'expecting_checkin_date' => 'Te Whakataunga Whakataunga Whakaaro:',
    'expires' => 'Ka puta',
    'Expiring_Assets_Report' => 'Nga Putanga Taonga Taonga.',
    'Expiring_Licenses_Report' => 'Ripoata Raihana Whakamutunga.',
    'hello' => 'Hiha',
    'hi' => 'Hi',
    'i_have_read' => 'Kua korerohia e au, kua whakaae ki nga tikanga whakamahi, kua riro mai hoki tenei mea.',
    'item' => 'Te nama:',
    'Item_Request_Canceled' => 'Te Whakakore i te Tono',
    'Item_Requested' => 'Ko te nama i tonoa',
    'link_to_update_password' => 'Koahia te hono e whai ake nei hei whakahou i to: kupuhipahipa:',
    'login_first_admin' => 'Whakauru ki to taahiranga hou Snipe-IT ma te whakamahi i nga taipitopito kei raro nei:',
    'login' => 'Whakauru:',
    'Low_Inventory_Report' => 'Pūrongo Inventory Low',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Min QTY',
    'name' => 'Ingoa',
    'new_item_checked' => 'Kua tohua tetahi mea hou i raro i to ingoa, kei raro iho nga korero.',
    'password' => 'Kupuhipa:',
    'password_reset' => 'Tautuhi Kupuhipa',

    'read_the_terms' => 'Tena koa korerotia nga tikanga o te whakamahi i raro.',
    'read_the_terms_and_click' => 'Tena koa panuihia nga tikanga whakamahi i raro nei, a ka pene i runga i te hono i raro ki te whakauru ka paahitia e koe me te whakaae ki nga tikanga o te whakamahinga, kua riro mai hoki te taonga.',
    'requested' => 'I tonohia:',
    'reset_link' => 'Tautuhi Hononga Kupuhipa',
    'reset_password' => 'Pāwhiri ki konei kia tautuhi i to kupuhipa:',
    'serial' => 'Waea',
    'supplier' => 'Kaihoko',
    'tag' => 'Tohu',
    'test_email' => 'Test Test from Snipe-IT',
    'test_mail_text' => 'He whakamatautau tenei mai i te Pūnaha Whakahaere Utu Snipe-IT. Mena kua whiwhi koe i tenei, kei te mahi te miihana :)',
    'the_following_item' => 'Kua tohua te mea e whai ake nei i:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Hei tautuhi i to: kupuhipa tukutuku, whakaoti i tenei puka:',
    'type' => 'Momo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Kaiwhakamahi',
    'username' => 'Ingoa Kaiwhakamahi',
    'welcome' => 'Nau mai: ingoa',
    'welcome_to' => 'Nau mai ki: web!',
    'your_credentials' => 'Nga tohu tohu Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/mi-NZ/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Nga ra',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Nga Putanga Taonga Taonga.',
    'Expiring_Licenses_Report' => 'Ripoata Raihana Whakamutunga.',
    'Item_Request_Canceled' => 'Te Whakakore i te Tono',
    'Item_Requested' => 'Ko te nama i tonoa',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Pūrongo Inventory Low',
    'a_user_canceled' => 'Kua whakakorea e tetahi kaiwhakamahi tetahi tonoemi i runga i te paetukutuku',
    'a_user_requested' => 'Kua tono tetahi kaiwhakamahi i tetahi mea i runga i te paetukutuku',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Ingoa Whakauru',
    'additional_notes' => 'Nga Tuhipoka Atu',
    'admin_has_created' => 'Kua hanga e tetahi kaiwhakahaere tetahi kaute mo koe i runga i te: paetukutuku tukutuku.',
    'asset' => 'Tahua',
    'asset_name' => 'Ingoa Ahua',
    'asset_requested' => 'Ka tonohia te taonga',
    'asset_tag' => 'Tae Taonga',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Tohua Ki To',
    'best_regards' => 'Ko nga whakaaro pai,',
    'canceled' => 'Kua whakakorehia',
    'checkin_date' => 'Rangi Titiro',
    'checkout_date' => 'Rā Rārangi',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Tena koahia te hono i raro ki te whakauru kua whiwhi koe i te taputapu.',
    'click_on_the_link_asset' => 'Koahia te hono i raro ki te whakauru kua riro ia koe te taonga.',
    'click_to_confirm' => 'Tena koahia te hono e whai ake nei hei whakauru i to:',
    'current_QTY' => 'QTY o nāianei',
    'days' => 'Nga ra',
    'expecting_checkin_date' => 'Ko te Whakataunga Whakataunga Whakaaro',
    'expires' => 'Ka puta',
    'hello' => 'Hiha',
    'hi' => 'Hi',
    'i_have_read' => 'Kua korerohia e au, kua whakaae ki nga tikanga whakamahi, kua riro mai hoki tenei mea.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Tuhinga',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Koahia te hono e whai ake nei hei whakahou i to: kupuhipahipa:',
    'login' => 'Whakauru:',
    'login_first_admin' => 'Whakauru ki to taahiranga hou Snipe-IT ma te whakamahi i nga taipitopito kei raro nei:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Ingoa',
    'new_item_checked' => 'Kua tohua tetahi mea hou i raro i to ingoa, kei raro iho nga korero.',
    'notes' => 'Tuhipoka',
    'password' => 'Kupuhipa',
    'password_reset' => 'Tautuhi Kupuhipa',
    'read_the_terms' => 'Tena koa korerotia nga tikanga o te whakamahi i raro.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'I tonohia',
    'reset_link' => 'Tautuhi Hononga Kupuhipa',
    'reset_password' => 'Pāwhiri ki konei kia tautuhi i to kupuhipa:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Waea',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Kaihoko',
    'tag' => 'Tohu',
    'test_email' => 'Test Test from Snipe-IT',
    'test_mail_text' => 'He whakamatautau tenei mai i te Pūnaha Whakahaere Utu Snipe-IT. Mena kua whiwhi koe i tenei, kei te mahi te miihana :)',
    'the_following_item' => 'Kua tohua te mea e whai ake nei i:',
    'to_reset' => 'Hei tautuhi i to: kupuhipa tukutuku, whakaoti i tenei puka:',
    'type' => 'Momo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Kaiwhakamahi',
    'username' => 'Ingoa Kaiwhakamahi',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Nau mai: ingoa',
    'welcome_to' => 'Nau mai ki: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Nga tohu tohu Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
